@@ -43,6 +43,18 @@ gboolean
 img_stop_export( img_window_struct *img );
 
 gboolean
-img_prepare_pixbufs( img_window_struct *img );
+img_prepare_pixbufs( img_window_struct *img,
+
+					 gboolean           preview );
+guint
+img_calc_next_slide_time_offset( img_window_struct *img,
+								 gdouble            rate );
+
+void
+img_render_transition_frame( img_window_struct *img );
+
+void
+img_render_still_frame( img_window_struct *img,
+						gdouble            rate );
 
 #endif
